#ifdef __cplusplus
extern "C" { 
#endif  

#include "f2c.h" 

int slaqsb_(char *uplo, integer *n, integer *kd, real *ab, integer *ldab, real *s, real *scond, real *amax, char *equed);

#ifdef __cplusplus
}
#endif