#ifdef __cplusplus
extern "C" { 
#endif  

#include "f2c.h" 

int zgttrf_(integer *n, doublecomplex *dl, doublecomplex *d__, doublecomplex *du, doublecomplex *du2, integer *ipiv, integer *info);

#ifdef __cplusplus
}
#endif